// IRrecvDemo02
// Remote controller test program
// Akinori Tsuji, Tokushima University

#include <IRremote.h>

int RECV_PIN = 11;
IRrecv irrecv(RECV_PIN);
decode_results results;

// key codes of the remote controller
enum {
  KEY_POWER    = 0xFF48B7,
  KEY_SOURCE   = 0xFF7887,
  KEY_UP       = 0xFF40BF,
  KEY_LEFT     = 0xFF20DF,
  KEY_DOWN     = 0xFF10EF,
  KEY_RIGHT    = 0xFF609F,
  KEY_OK       = 0xFFA05F,
  KEY_MENU     = 0xFF50AF,
  KEY_VOL_DOWN = 0xFF30CF,
  KEY_VOL_OFF  = 0xFFF807,
  KEY_VOL_UP   = 0xFF708F, 
  KEY_REPEAT   = 0xFFFFFFFF,
  KEY_UNKNOWN  = 0
};

void setup() {
  Serial.begin(9600);
  ir_enable();
}

void loop() {
  // if there is an ir code, process it
  if (ir_stat() == true) {
    process_result();
    ir_resume(); // resume receiver
  }
}



void process_result() {
  int code = ir_key();
  switch (code) {
  case KEY_POWER:
    {
      Serial.println("Power ON");
    } 
    break;
  case KEY_SOURCE: 
    {
      Serial.println("Source");
    } 
    break;
  case KEY_UP: 
    {
      Serial.println("UP");
    } 
    break;
  case KEY_DOWN: 
    {
      Serial.println("DOWN");
    } 
    break;
  case KEY_LEFT: 
    {
      Serial.println("LEFT");
    } 
    break;
  case KEY_RIGHT: 
    {
      Serial.println("RIGHT");
    } 
    break;
  case KEY_OK: 
    {
      Serial.println("OK");
    } 
    break;
  case KEY_MENU: 
    {
      Serial.println("MENU");
    } 
    break;
  case KEY_VOL_DOWN: 
    {
      Serial.println("VOL_DOWN");
    } 
    break;
  case KEY_VOL_OFF: 
    {
      Serial.println("VOL_OFF");
    } 
    break;
  case KEY_VOL_UP: 
    {
      Serial.println("VOL_UP");
    } 
    break;
  case KEY_REPEAT:
    {
      Serial.println("REPEAT");
    } 
    break;
  default:
    break;
  }
}

//---------------------------------------------------------
// IR functions
//---------------------------------------------------------
void ir_enable() {
  irrecv.enableIRIn(); // Start the receiver
}

bool ir_stat() {
  return irrecv.decode(&results); // check the status of ir receiver
}

unsigned long ir_key() {
  return results.value; // return ir received code
}

void ir_resume() {
  irrecv.resume(); // resume receiver
}



